%%% Code for selection-corrected quantile regression
%%% by Manuel Arellano and Stephane Bonhomme

%%%% The code makes use of rq.m

%%% Inputs:
%%% participation indicator D (binary)
%%% outcome variable Y (note: values of Y for D=0 are arbitrary, they may even be missing)
%%% matrix of covariates X, not including the constant
%%% matrix of excluded covariates B, not including the constant.
%%% Z=(X,B) is constructed below

%%% Specification in this version:
%%% propensity score: probit
%%% copula: Gaussian
%%% instrument function: varphi(Z) = propensity score p(Z)
%%% grid of tau's for tau=.2,...,.8
%%% estimates of beta(tau) for tau=.05,...,.95
%%% grid search for rho with 99 equidistant values

%%% Estimate propensity score
Z=[X B];
gamma=glmfit(Z,D,'binomial','link','probit');
pZ=normcdf(gamma(1)+Z*gamma(2:end));

%%% Instrument function
varphi=pZ;

%%% Select participants
Y1=Y(D==1);
pZ1=pZ(D==1);
X1=X(D==1,:);
varphi1=varphi(D==1);
[N1 colx]=size(X1);

%%% Percentile values to estimate rho
vectau=(.20:.20:.80)';
[t n]=size(vectau);

%%% Start loop on rho
vecrhoa=(-.98:.02:.98)';
[s n]=size(vecrhoa);

%%% Objective function to be minimized
warning('off')
object=zeros(s,1);
for j=1:s
    rhoa=vecrhoa(j);
    obj=0;
        for k=1:t
            tau=vectau(k);
            %%% Gaussian copula
            G=copulacdf('Gaussian',[tau*ones(N1,1) pZ1],rhoa)./pZ1;
            %%% Rotated quantile regression
            beta=rq([ones(N1,1) X1],Y1,G);
            obj=obj+(mean(varphi1.*((Y1<=beta(1)+X1*beta(2:colx+1))-G)));
         end        
    object(j)=obj^2;
    j
end

%%% Minimize the objective function
[C I]=min(object);
rho=vecrhoa(I);

%%% Optional: plot objective function
%plot(vecrhoa(10:90),object(10:90))

%%% Estimate selection-corrected quantile parameters beta(tau)
%%% Here: at centiles
beta=zeros(colx+1,19);
for tau=.05:.05:.95
    %%% Gaussian copula
    G=copulacdf('Gaussian',[tau*ones(N1,1) pZ1],rho)./pZ1;
    %%% Rotated quantile regression
    beta(:,round(20*tau))=rq([ones(N1,1) X1],Y1,G);
end

%%% Outputs
display('copula parameter') 
rho
display('quantile coefficients') 
beta
%%% Note: the first column in beta corresponds to the intercept. 
%%% different columns are tau=.05 to tau=.95
