/* Stata code for Arellano and Bonhomme, "Quantile Selection Models" */
/* This code constructs the dataset to be used in the equilibrium analysis in Section 4.3  */
/* It is based on part of par_boot.do written in Blundell et al (2007, Econometrica) */
/* It uses wagedata.dta */


clear matrix

set matsize 400
set trace off
set seed 2
clear
set mem 500m
set more 1

cd C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata

** first clean up raw data
u wagedata, clear

* clean wage
replace wage = . if work==0 |wage==0
gen x = wage==.
so x sex year wage
qui by x sex year : replace wage=. if _n<10 |_N-_n<10
gen lw = log(wage)

* drop missing observations
drop if work==1 & lw==.

* drop self-employed
drop if self==1

* keep if education is reported
keep if educ~=.

* education
gen edu=(educ==18)

* gender (1: females)
gen gender=(sex==2)

* out-of work income
replace ben_inc = . if ben_inc<=0
replace ben_inc = log(ben_inc)

* keep if instruments are available
keep if ben_inc~=.




* instruments
gen s0_zero=(1-couple)*(1-gender)*ben_inc
gen s1_zero=(1-couple)*(gender)*ben_inc
gen m0_zero=(couple)*(1-gender)*ben_inc
gen m1_zero=(couple)*(gender)*ben_inc

* marital status
gen married=couple

* cohort
gen cohort=year+1900-age
gen c1919_34=(cohort>=1919)*(cohort<=1934)
gen c1935_44=(cohort>=1935)*(cohort<=1944)
gen c1955_64=(cohort>=1955)*(cohort<=1964)
gen c1965_77=(cohort>=1965)*(cohort<=1977)

* age squared
gen age_sq=age^2

* region
local j=1
while `j'<=11{
gen reg_d`j'=(region==`j')
local j=`j'+1
}

* kids
gen kids_d1=kids1
gen kids_d2=kids2
gen kids_d3=kids34
gen kids_d4=kids510
gen kids_d5=kids1116
gen kids_d6=kids1718

drop index

* interactions
gen married_gender=married*gender
gen edu_gender=edu*gender
gen age_gender=age*gender
gen age_sq_gender=age_sq*gender
gen c1919_34_gender=c1919_34*gender 
gen c1935_44_gender=c1935_44*gender 
gen c1955_64_gender=c1955_64*gender 
gen c1965_77_gender=c1965_77*gender

* Graph out-of-work income
gen nowork_inc=exp(ben_inc)
gen var_year=_n+77 if _n<=23 
gen quantinc10_0=.
gen quantinc50_0=.
gen quantinc90_0=.

gen quantinc10_1=.
gen quantinc50_1=.
gen quantinc90_1=.

local j=78
while `j'<=100{
_pctile nowork_inc if year==`j' & gender==0, p(10 50 90)
replace quantinc10_0=r(r1) if var_year==`j'
replace quantinc50_0=r(r2) if var_year==`j'
replace quantinc90_0=r(r3) if var_year==`j'
_pctile nowork_inc if year==`j' & gender==1, p(10 50 90)
replace quantinc10_1=r(r1) if var_year==`j'
replace quantinc50_1=r(r2) if var_year==`j'
replace quantinc90_1=r(r3) if var_year==`j'
local j=`j'+1
}

/*
twoway scatter quantinc10_0 quantinc50_0 quantinc90_0 var_year if var_year<=2000, /*
*/ c(l l l) ms(p p p) lwidth(medthick medthick medthick) /*
*/ lpattern(solid solid solid) legend(off) xtitle("year") ytitle("out of work income")

twoway scatter quantinc10_1 quantinc50_1 quantinc90_1 var_year if var_year<=2000, /*
*/ c(l l l) ms(p p p) lwidth(medthick medthick medthick) /*
*/ lpattern(solid solid solid) legend(off) xtitle("year") ytitle("out of work income")
*/
local j=78
while `j'<=100{
_pctile nowork_inc if year==`j' & gender==0 & c1919_34==1, p(10 50 90)
replace quantinc10_0=r(r1) if var_year==`j'
replace quantinc50_0=r(r2) if var_year==`j'
replace quantinc90_0=r(r3) if var_year==`j'
_pctile nowork_inc if year==`j' & gender==1 & c1919_34==1, p(10 50 90)
replace quantinc10_1=r(r1) if var_year==`j'
replace quantinc50_1=r(r2) if var_year==`j'
replace quantinc90_1=r(r3) if var_year==`j'
local j=`j'+1
}

replace var_year=var_year+1900


twoway scatter quantinc10_0 quantinc50_0 quantinc90_0 var_year if var_year<=2000, /*
*/ c(l l l) ms(p p p) lwidth(medthick medthick medthick) /*
*/ lpattern(solid solid solid) legend(off) xtitle("year") ytitle("out of work income")

twoway scatter quantinc10_1 quantinc50_1 quantinc90_1 var_year if var_year<=2000, /*
*/ c(l l l) ms(p p p) lwidth(medthick medthick medthick) /*
*/ lpattern(solid solid solid) legend(off) xtitle("year") ytitle("out of work income")

* participation probit
xi: probit work s0_zero s1_zero m0_zero m1_zero edu edu_gender c1919_34 c1935_44 c1955_64 c1965_77 /*
*/ age age_sq age_gender age_sq_gender c1919_34_gender c1935_44_gender c1955_64_gender c1965_77_gender/*
*/ reg_d* kids_d* married gender married_gender i.year*edu

predict pZ

* dummies
local j=79
while `j'<=100{
gen d`j'=(year==`j')
local j=`j'+1
}

local j=79
while `j'<=100{
gen dedu`j'=(year==`j')*edu
local j=`j'+1
}

* save dataset

keep lw work pZ gender married edu edu_gender married_gender c1919_34 c1935_44 c1955_64 c1965_77 /*
*/ age age_sq age_gender age_sq_gender c1919_34_gender c1935_44_gender c1955_64_gender c1965_77_gender /*
*/ reg_d* kids_d* d79-d100 dedu79-dedu100 s0_zero s1_zero m0_zero m1_zero year
order lw work pZ gender married edu edu_gender married_gender c1919_34 c1935_44 c1955_64 c1965_77 /*
*/ age age_sq age_gender age_sq_gender c1919_34_gender c1935_44_gender c1955_64_gender c1965_77_gender /*
*/ reg_d* kids_d* d79-d100 dedu79-dedu100 s0_zero s1_zero m0_zero m1_zero year
saveold data_GE_interact, replace

outsheet lw work pZ gender married edu edu_gender married_gender c1919_34 c1935_44 c1955_64 c1965_77 /*
*/ age age_sq age_gender age_sq_gender c1919_34_gender c1935_44_gender c1955_64_gender c1965_77_gender /*
*/ reg_d* kids_d* d79-d100 dedu79-dedu100/*
*/ s0_zero s1_zero m0_zero m1_zero year using data_GE_interact, comma replace



